@@ -16,8 +16,8 @@ use POE::Component::IRC::Plugin::Whois;
 use Socket;
 use base qw(POE::Component::Pluggable);
 
-our $VERSION = '5.82';
-our $REVISION = do {my@r=(q$Revision: 688 $=~/\d+/g);sprintf"%d"."%04d"x$#r,@r};
+our $VERSION = '5.86';
+our $REVISION = do {my@r=(q$Revision: 703 $=~/\d+/g);sprintf"%d"."%04d"x$#r,@r};
 our ($GOT_SSL, $GOT_CLIENT_DNS, $GOT_SOCKET6, $GOT_ZLIB);
 
 BEGIN {
@@ -348,6 +348,7 @@ sub _sock_down {
     $self->_compress_uplink( 0 );
     $self->_compress_downlink( 0 );
     $self->{ircd_compat}->chantypes( [ '#', '&' ] );
+    $self->{ircd_compat}->identifymsg(0);
 
     # post a 'irc_disconnected' to each session that cares
     $self->_send_event(irc_disconnected => $self->{server} );
@@ -899,6 +900,7 @@ sub spawn {
         prefix     => 'irc_',
         reg_prefix => 'PCI_',
         types      => { SERVER => 'S', USER => 'U' },
+        ($self->{plugin_debug} ? (debug => 1) : () ),
     );
 
     my $options = delete $params{options};
@@ -1510,9 +1512,18 @@ sub S_nick {
     return PCI_EAT_NONE;
 }
 
+# tell POE::Filter::IRC::Compat to handle IDENTIFY-MSG
+sub S_290 {
+    my ($self, $irc) = splice @_, 0, 2;
+    my $text = ${ $_[1] };
+    $self->{ircd_compat}->identifymsg(1) if $text eq 'IDENTIFY-MSG';
+    return PCI_EAT_NONE;
+}
+
 sub S_isupport {
     my ($self, $irc) = splice @_, 0, 2;
     $self->{ircd_compat}->chantypes( $self->{isupport}->isupport('CHANTYPES') || [ '#', '&' ] );
+    $irc->yield(quote => 'CAPAB IDENTIFY-MSG') if $self->{isupport}->isupport('CAPAB');
     return PCI_EAT_NONE;
 }
 
@@ -1767,7 +1778,7 @@ to gain ops.
 
 Both constructors return an object. The object is also available within 'irc_'
 event handlers by using C<< $_[SENDER]->get_heap() >>. See also
-L<C<register>|/"register"> and L<C<irc_registered>|"/irc_registered">.
+L<C<register>|/"register"> and L<C<irc_registered>|/"irc_registered">.
 
 =head2 C<spawn>
 
@@ -2170,7 +2181,7 @@ like to use formatting and color codes in your messages.
 Tells the IRC server to disconnect you. Takes one optional argument:
 some clever, witty string that other users in your channels will see
 as you leave. You can expect to get an
-L<C<irc_disconnect>|/"irc_disconnect"> event shortly after sending this.
+L<C<irc_disconnected>|/"irc_disconnected"> event shortly after sending this.
 
 =head3 C<shutdown>
 
@@ -2238,8 +2249,8 @@ documentation for DCC-related commands.
 
 =head3 C<info>
 
-Basically the same as the "version" command, except that the server is
-permitted to return any information about itself that it thinks is
+Basically the same as the L<C<version>|/"version"> command, except that the
+server is permitted to return any information about itself that it thinks is
 relevant. There's some nice, specific standards-writing for ya, eh?
 
 =head3 C<invite>
@@ -2459,8 +2470,8 @@ in. ARG0 is the server name.
 
 B<NOTE:> When you get an C<irc_connected> event, this doesn't mean you
 can start sending commands to the server yet. Wait until you receive
-an C<irc_001> event (the server welcome message) before actually sending
-anything back to the server.
+an L<C<irc_001>|/"All numeric events"> event (the server welcome message)
+before actually sending anything back to the server.
 
 =head3 C<irc_ctcp>
 
@@ -2481,7 +2492,9 @@ For instance, receiving a CTCP PING request generates an C<irc_ctcp_ping>
 event, CTCP ACTION (produced by typing "/me" in most IRC clients)
 generates an C<irc_ctcp_action> event, blah blah, so on and so forth. ARG0
 is the nick!hostmask of the sender. ARG1 is the channel/recipient
-name(s). ARG2 is the text of the CTCP message.
+name(s). ARG2 is the text of the CTCP message. On servers supporting the
+CAPAB IDENTIFY-MSG feature (e.g. FreeNode), CTCP ACTIONs will have ARG3,
+which will be 1 if the sender has identified with NickServ, 0 otherwise.
 
 Note that DCCs are handled separately -- see the
 L<DCC plugin|POE::Component::IRC::Plugin::DCC>.
@@ -2537,7 +2550,8 @@ hostmasks, channel keys, whatever).
 Sent whenever you receive a PRIVMSG command that was addressed to you
 privately. ARG0 is the nick!hostmask of the sender. ARG1 is an array
 reference containing the nick(s) of the recipients. ARG2 is the text
-of the message.
+of the message. On FreeNode there is also ARG3, which will be 1 if the
+sender has identified with NickServ, 0 otherwise.
 
 =head3 C<irc_nick>
 
@@ -2562,7 +2576,8 @@ person's nick!hostmask. ARG1 is the channel name. ARG2 is the part message.
 Sent whenever you receive a PRIVMSG command that was sent to a
 channel. ARG0 is the nick!hostmask of the sender. ARG1 is an array
 reference containing the channel name(s) of the recipients. ARG2 is
-the text of the message.
+the text of the message. On FreeNode there is also ARG3, which will be
+1 if the sender has identified with NickServ, 0 otherwise.
 
 =head3 C<irc_quit>
 
@@ -2639,8 +2654,8 @@ session.
 
 =head3 C<irc_isupport>
 
-Emitted by the first event after an C<irc_005>, to indicate that isupport
-information has been gathered. ARG0 is the
+Emitted by the first event after an L<C<irc_005>|/"All numeric events">, to
+indicate that isupport information has been gathered. ARG0 is the
 L<POE::Component::IRC::Plugin::ISupport|POE::Component::IRC::Plugin::ISupport>
 object.
 
@@ -2649,7 +2664,7 @@ object.
 Emitted on a succesful addition of a delayed event using the
 L<C<delay>|/"delay"> method. ARG0 will be the alarm_id which can be used
 later with L<C<delay_remove>|/"delay_remove">. Subsequent parameters are
-the arguments that were passed to C<delay>.
+the arguments that were passed to L<C<delay>|/"delay">.
 
 =head3 C<irc_delay_removed>
 
@@ -2667,7 +2682,7 @@ as to what went wrong. Hopefully.
 
 Emitted whenever a SOCKS connection is rejected by a SOCKS server. ARG0 is
 the SOCKS code, ARG1 the SOCKS server address, ARG2 the SOCKS port and ARG3
-the SOCKS user id ( if defined ).
+the SOCKS user id (if defined).
 
 =head2 Somewhat Less Important Events
 
@@ -2740,7 +2755,7 @@ _start handler:
  }
 
 Each poco-irc will send your session an
-L<C<irc_registered>|/"irc_register"> event:
+L<C<irc_registered>|/"irc_registered"> event:
 
  sub irc_registered {
      my ($kernel, $sender, $heap, $irc_object) = @_[KERNEL, SENDER, HEAP, ARG0];
