@@ -3,11 +3,9 @@ package POE::Component::IRC::Plugin::Connector;
 use strict;
 use warnings;
 use POE;
-use POE::Component::IRC;
 use POE::Component::IRC::Plugin qw( :ALL );
-use vars qw($VERSION);
 
-$VERSION = '1.1';
+our $VERSION = '1.1';
 
 sub new {
     my ($package, %args) = @_;
@@ -24,7 +22,6 @@ sub PCI_register {
         object_states => [
             $self => [ qw(_start _auto_ping _reconnect _shutdown _start_ping _start_time_out _stop_ping _time_out) ],
         ],
-        options => { trace => 0 },
     )->ID();
 
     $irc->plugin_register( $self, 'SERVER', qw(all) );
@@ -76,7 +73,7 @@ sub S_socketerr {
 sub S_pong {
     my ($self, $irc) = splice @_, 0, 2;
     my $ping = shift @{ $self->{pings} };
-    return PCI_EAT_NONE unless $ping;
+    return PCI_EAT_NONE if !$ping;
     $self->{lag} = time() - $ping;
     $self->{seen_traffic} = 1;
     return PCI_EAT_NONE;
@@ -141,8 +138,8 @@ sub _shutdown {
 sub _reconnect {
     my ($kernel, $self, $session, $sender) = @_[KERNEL, OBJECT, SESSION, SENDER];
 
-    my %args = ();
-    if (ref $self->{servers} eq 'ARRAY' && scalar @{ $self->{servers} }) {
+    my %args;
+    if (ref $self->{servers} eq 'ARRAY' && @{ $self->{servers} }) {
         @args{qw(Server Port)} = @{ $self->{servers}->[0] };
         push @{ $self->{servers} }, shift @{ $self->{servers} };
     }
@@ -221,9 +218,7 @@ L<http://poe.perl.org/?POE_Cookbook/IRC_Bot_Reconnecting>.
 
 =head1 METHODS
 
-=over
-
-=item C<new>
+=head2 C<new>
 
 Takes two optional arguments:
 
@@ -237,13 +232,11 @@ The plugin will cycle through this list of servers whenever it reconnects.
 Returns a plugin object suitable for use in
 L<POE::Component::IRC|POE::Component::IRC>'s C<plugin_add> method.
 
-=item C<lag>
+=head2 C<lag>
 
 Returns the current 'lag' in seconds between sending PINGs to the IRC server
 and getting PONG responses. Probably not likely to be wholely accurate.
 
-=back
-
 =head1 AUTHOR
 
 Chris "BinGOs" Williams <chris@bingosnet.co.uk>
